@@ -1,6 +1,6 @@
 from ipaddress import ip_network, ip_address
 from pulumi import ComponentResource, ResourceOptions, StackReference
-from ..resources import route_table, vnet, firewall, vpn_gateway, bastion_hosts, resource_group
+from resources import route_table, vnet, firewall, vpn_gateway, bastion_hosts, resource_group
 
 
 class Hub(ComponentResource):
